def calculate_area(diameter):
    """
    根据给定的风力涡轮机叶轮直径计算扫过面积的函数。

    参数:
    - diameter: 风力涡轮机叶轮的直径，单位：米（m）

    返回:
    - A: 风力涡轮机叶片扫过的面积，单位：平方米（m^2）
    """
    radius = diameter / 2
    A = 3.141592653589793 * radius ** 2
    return A

def calculate_cp(P, A, rho, v):
    """
    计算风能利用系数Cp的函数。

    参数:
    - P: 风力涡轮机的输出功率，单位：瓦特（W）
    - A: 风力涡轮机叶片扫过的面积，单位：平方米（m^2）
    - rho: 空气密度，单位：千克每立方米（kg/m^3）
    - v: 风速，单位：米每秒（m/s）

    返回:
    - Cp: 风能利用系数
    """
    Cp = P / (0.5 * rho * A * v ** 3)
    return Cp

# 示例变量
diameter_example = 82 # 假设叶轮直径为46.2米
P_example = 76.32*1000
rho_example = 1.059
v_example = 3.01

# 使用函数计算A
A_example = calculate_area(diameter_example)

# 使用计算得到的A值调用calculate_cp函数
cp_value = calculate_cp(P_example, A_example, rho_example, v_example)

print("Cp={}".format(cp_value))
